@@ -1,7 +1,6 @@
 #include "riptide_python_test.h"
 
-#define BOOST_UT_DISABLE_MODULE
-#include "../ut/include/boost/ut.hpp"
+#include "boost/ut.hpp"
 
 #include <array>
 #include <vector>
